==> volcano-model-v1beta1-5.11.2-sources.jar: annotations/io/fabric8/volcano/scheduling/v1beta1/QueueSpecFluentImpl.java <==
package io.fabric8.volcano.scheduling.v1beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class QueueSpecFluentImpl<A extends io.fabric8.volcano.scheduling.v1beta1.QueueSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.volcano.scheduling.v1beta1.QueueSpecFluent<A>{
  public QueueSpecFluentImpl() {
  }
  public QueueSpecFluentImpl(io.fabric8.volcano.scheduling.v1beta1.QueueSpec instance) {
    this.withCapability(instance.getCapability()); 
    this.withReclaimable(instance.getReclaimable()); 
    this.withWeight(instance.getWeight()); 
  }
  private java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> capability;
  private java.lang.Boolean reclaimable;
  private java.lang.Integer weight;
  public A addToCapability(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value) {
    if(this.capability == null && key != null && value != null) { this.capability = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(key != null && value != null) {this.capability.put(key, value);} return (A)this;
  }
  public A addToCapability(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.capability == null && map != null) { this.capability = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(map != null) { this.capability.putAll(map);} return (A)this;
  }
  public A removeFromCapability(java.lang.String key) {
    if(this.capability == null) { return (A) this; }
    if(key != null && this.capability != null) {this.capability.remove(key);} return (A)this;
  }
  public A removeFromCapability(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.capability == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.capability != null){this.capability.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getCapability() {
    return this.capability;
  }
  public <K,V>A withCapability(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> capability) {
    if (capability == null) { this.capability =  null;} else {this.capability = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(capability);} return (A) this;
  }
  public java.lang.Boolean hasCapability() {
    return this.capability != null;
  }
  public java.lang.Boolean getReclaimable() {
    return this.reclaimable;
  }
  public A withReclaimable(java.lang.Boolean reclaimable) {
    this.reclaimable=reclaimable; return (A) this;
  }
  public java.lang.Boolean hasReclaimable() {
    return this.reclaimable != null;
  }
  public java.lang.Integer getWeight() {
    return this.weight;
  }
  public A withWeight(java.lang.Integer weight) {
    this.weight=weight; return (A) this;
  }
  public java.lang.Boolean hasWeight() {
    return this.weight != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    QueueSpecFluentImpl that = (QueueSpecFluentImpl) o;
    if (capability != null ? !capability.equals(that.capability) :that.capability != null) return false;
    if (reclaimable != null ? !reclaimable.equals(that.reclaimable) :that.reclaimable != null) return false;
    if (weight != null ? !weight.equals(that.weight) :that.weight != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(capability,  reclaimable,  weight,  super.hashCode());
  }
  
}

==> volcano-model-v1beta1-5.12.3-sources.jar: annotations/io/fabric8/volcano/scheduling/v1beta1/QueueSpecFluentImpl.java <==
package io.fabric8.volcano.scheduling.v1beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class QueueSpecFluentImpl<A extends io.fabric8.volcano.scheduling.v1beta1.QueueSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.volcano.scheduling.v1beta1.QueueSpecFluent<A>{
  public QueueSpecFluentImpl() {
  }
  public QueueSpecFluentImpl(io.fabric8.volcano.scheduling.v1beta1.QueueSpec instance) {
    this.withCapability(instance.getCapability()); 
    this.withReclaimable(instance.getReclaimable()); 
    this.withWeight(instance.getWeight()); 
  }
  private java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> capability;
  private java.lang.Boolean reclaimable;
  private java.lang.Integer weight;
  public A addToCapability(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value) {
    if(this.capability == null && key != null && value != null) { this.capability = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.capability.put(key, value);} return (A)this;
  }
  public A addToCapability(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.capability == null && map != null) { this.capability = new java.util.LinkedHashMap(); }
    if(map != null) { this.capability.putAll(map);} return (A)this;
  }
  public A removeFromCapability(java.lang.String key) {
    if(this.capability == null) { return (A) this; }
    if(key != null && this.capability != null) {this.capability.remove(key);} return (A)this;
  }
  public A removeFromCapability(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.capability == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.capability != null){this.capability.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getCapability() {
    return this.capability;
  }
  public <K,V>A withCapability(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> capability) {
    if (capability == null) { this.capability =  null;} else {this.capability = new java.util.LinkedHashMap(capability);} return (A) this;
  }
  public java.lang.Boolean hasCapability() {
    return this.capability != null;
  }
  public java.lang.Boolean getReclaimable() {
    return this.reclaimable;
  }
  public A withReclaimable(java.lang.Boolean reclaimable) {
    this.reclaimable=reclaimable; return (A) this;
  }
  public java.lang.Boolean hasReclaimable() {
    return this.reclaimable != null;
  }
  public java.lang.Integer getWeight() {
    return this.weight;
  }
  public A withWeight(java.lang.Integer weight) {
    this.weight=weight; return (A) this;
  }
  public java.lang.Boolean hasWeight() {
    return this.weight != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    QueueSpecFluentImpl that = (QueueSpecFluentImpl) o;
    if (capability != null ? !capability.equals(that.capability) :that.capability != null) return false;
    if (reclaimable != null ? !reclaimable.equals(that.reclaimable) :that.reclaimable != null) return false;
    if (weight != null ? !weight.equals(that.weight) :that.weight != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(capability,  reclaimable,  weight,  super.hashCode());
  }
  
}
